from setuptools import find_packages, setup

setup(
    name='blns',
    version='0.1.7',
    url='https://github.com/danggrianto/big-list-of-naughty-strings',
    license='MIT',
    author='Daniel Anggrianto',
    author_email='daniel@anggrianto.com',
    description='Big List of Naughty String. Forked from https://github.com/minimaxir/big-list-of-naughty-strings',
    keywords='Big List of Naughty String',
    packages=['blns'],
    platforms='any',
)
